Source documentation
====================


:mod:`almir` -- Main package
****************************

.. automodule:: almir


:mod:`almir.forms` -- HTML forms definitions
--------------------------------------------

.. automodule:: almir.forms
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.meta` -- Configuration for models
---------------------------------------------
.. automodule:: almir.meta
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.models` -- SQLAlchemy models
----------------------------------------
.. automodule:: almir.models
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.views` -- Pyramid views
-----------------------------------
.. automodule:: almir.views
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.lib` -- Non MVC code
--------------------------------

.. automodule:: almir.lib


:mod:`almir.lib.bacula_base64` -- Bacula custom base64 implmentation
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.lib.bacula_base64
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.lib.bconsole` -- Python interface to bconsole
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.lib.bconsole
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.lib.console_commands` -- Parsed list of bconsole commands
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.lib.console_commands
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`almir.lib.sqlalchemy_custom_types`
++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.lib.sqlalchemy_custom_types
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`almir.lib.sqlalchemy_declarative_reflection`
++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.lib.sqlalchemy_declarative_reflection
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.lib.sqlalchemy_lowercase_inspector`
+++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.lib.sqlalchemy_lowercase_inspector
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.lib.utils` - General utilities
++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.lib.utils
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.scripts` -- Runnable scripts package
------------------------------------------------

.. automodule:: almir.scripts


:mod:`almir.scripts.configure_deploy` -- Ask few questions and configure almir
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.scripts.configure_deploy
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.scripts.parse_console_commands` -- Parse help commands from bconsole source
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.scripts.parse_console_commands
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`almir.tests` -- Tests package
-----------------------------------

.. automodule:: almir.tests



:mod:`almir.tests.test_functional` -- Functional tests
++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: almir.tests.test_functional
   :members:
   :undoc-members:
   :show-inheritance:
